timespantools.timespan_2_stops_after_timespan_1_starts
======================================================

.. autofunction:: abjad.tools.timespantools.timespan_2_stops_after_timespan_1_starts.timespan_2_stops_after_timespan_1_starts
